'use strict';

const fs = require('fs');
const path = require('path');
const paths = require('../config/paths');

let name = '';
let dir = '';
const distIndex = process.argv.indexOf('--dist');

if (distIndex === -1) {
  name = process.argv[2];
  dir = `/components/${name}`;
} else {
  name = process.argv[distIndex + 2];
  dir = path.join(process.argv[distIndex + 1], name);
}

dir = dir.split('/').reduce((dir_, dirname) => {
  dir_ = path.join(dir_, dirname);
  // console.log(dir_)
  if (!fs.existsSync(dir_)) {
    fs.mkdirSync(dir_);
  }

  return dir_;
}, paths.appSrc);

const trim = str => str.trim().replace(/^ {2}/gm, '');

const write = (path, content) => {
  fs.writeFileSync(path, trim(content), 'utf-8');
};

const index = `
  import ${name} from './${name}';
  import './${name}.scss';
  
  export default ${name};
  `;

const jsx = `
  import React from 'react';
  
  export default function ${name}() {
    return (
      <div className="${name
        .split(/(?=[A-Z])/)
        .map(str => str.toLocaleLowerCase())
        .join('-')}"></div>
    );
  }
  `;

const scss = '';

write(`${dir}/index.js`, index);
write(`${dir}/${name}.jsx`, jsx);
write(`${dir}/${name}.scss`, scss);

process.exit(0);
